<?php
/********************************************************************************
 *	BizyCorp/Ekwa Internal development Team
 *	
 *	This object writes an access log entry 
 *	
 *	Author            :- Nuwan Wickramarathne
 *  Creation date     :- Jan 03, 2014
 *  Last Modified on  :- 
 *  Last Modification :- 
 */

if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Log_Object{
	protected $serverDetails = array(
		'Referer' => 'HTTP_REFERER,-',
		'Gateway'=>'REMOTE_ADDR,-', 
		'Server port'=>'SERVER_PORT,80', 
		'Remote port'=>'REMOTE_PORT,-',
		'Server name'=>'SERVER_NAME,-',
		'Request method'=>'REQUEST_METHOD,GET',
		'Request uri'=>'REQUEST_URI, ',
		'User agent'=>'HTTP_USER_AGENT, '
	);
	protected $otherDetails='';
	protected $date = '';
	protected $serverData = '';
	protected $user_name = '';
	protected $memtype = '';
	protected $save_path='./application/logs/access';
	
	function __construct(){
		
		date_default_timezone_set('UTC');
		$this->date = date('Y-m-d H:i:s e');
		
		// In order to work file write_file() helper function we need CI file helper.
		// to call internal CI helpers/libraries from inside another library we have to use fullowing 
		// decleration method. MRMR 18/8/2014
		$CI =& get_instance();
		$CI->load->helper('file');
		
	}//end of construct
	
	//set methodes
	/**
	 * set_serverDetails function
	 * This is a public function. To set details need to get from server to add in to log file
	 * @param multiarray $serverDetails
	 */
	public function set_serverDetails($serverDetails){
		$this->serverDetails=$serverDetails;
	}
	
	/**
	 * set_otherDetails function
	 * This is a public function. To set other Details need to add in to log file
	 * @param multiarray $otherDetails
	 */
	public function set_otherDetails($otherDetails){
		$this->otherDetails=$otherDetails;
	}
	
	/**
	 * set_userDetails
	 * To set user id and user Type.
	 * @param string $useId
	 * @param string $useType
	 */
	public function set_userDetails($userName='', $userType=''){
		$this->user_name= ($userName!='')?$userName:'-';
		$this->memtype = ($userType!='')?$userType:'-';
	}
	
	/**
	 * set_path function
	 * This is a public function to set access log file path.
	*/
	public function set_path($path=''){
		$this->save_path = $path;
	}
	
	/**
	 * getIP function
	 * This is a private function to get client ip address.
	 */
	private function getIP() { 
		if (getenv("HTTP_CLIENT_IP")) 
			$ip = getenv("HTTP_CLIENT_IP");
		else if (getenv("HTTP_X_FORWARDED_FOR")) 
			$ip = getenv("HTTP_X_FORWARDED_FOR");
		else if (getenv("REMOTE_ADDR")) 
			$ip = getenv("REMOTE_ADDR");
		else 
			$ip = "UNKNOWN";
			
		return $ip;
	}
	
	/**
	 * get_variable function
	 * This is a private function to get more server and client details.
	 */
	private function get_variable() {
		$data = array();
		foreach ($this->serverDetails as $keyName=>$value){
			$data = explode(",",$value);
			$this->serverData[$keyName] = getenv($data[0])? getenv($data[0]):$data[1];
		}		
	    unset($data);
	}
	
	/**
	 * init function
	 * This is a public function. This to initialized log
	 */
	public function init(){
		$rowId 	= "'".microtime()."'";
		
		$errorLog="
			<row id=$rowId>/n
 	 			<cell fieldName='Date Created'><![CDATA[".$this->date."]]></cell>/n
  				<cell fieldName='User id'><![CDATA[".$this->user_name."]]></cell>/n
  				<cell fieldName='Member type'><![CDATA[".$this->memtype."]]></cell>/n
 	 			<cell fieldName='IP address'><![CDATA[".$this->getIP()."]]></cell>/n";
		
		if(isset($this->serverDetails)){
			$this->get_variable();
			foreach ($this->serverData as $key=>$values){
				$errorLog .= "<cell fieldName='".$key."'><![CDATA[".$values."]]></cell>/n";
			}
		}
		
		if(is_array($this->otherDetails)){
			foreach ($this->otherDetails as $key=>$values){
				if(is_array($values))
					$values = serialize($values);
					
				$errorLog .= "<cell fieldName='".$key."'><![CDATA[".$values."]]></cell>/n";
			}
		}
		$errorLog.='</row>/n';
		
		if (!file_exists($this->save_path.'/AL-'.date('Y-m-d').'.xml')){
			// Check if supplied path folders are created first.If not creat them first
			// then proceed with log file creation. MRMR 18/8/2014
			if($this->rmkdir($this->save_path)){
	    		write_file($this->save_path.'/AL-'.date('Y-m-d').'.xml',null);
			}
	  	}
	  	$logfile 	= get_filenames($this->save_path,true);
  		$logfile 	= str_replace('\\','/',$logfile[0]);
  		$logfile 	= substr($logfile,0,strripos($logfile,'/'));
  		$logfile .= '/AL-'. date('Y-m-d').'.xml' ;
  				
 	 	error_log($errorLog,3,$logfile);
	}
	
	/**
	 * get_xml function
	 * This is a public function. This out XML file for DHTML grid 
	 * @param strign $logDate
	 * @param array $widths
	 * @param array $collist
	 * @return string :- XML output
	 */
	public function get_xml($logDate, $widths, $collist){
		ob_start();
  		echo "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n";
  			echo "<rows>\n"; 
     			echo "<head>\n";
     			
     			if(isset($collist)){
     				foreach ($collist as $key){
     					echo "
     						<column type='ro' align='center' sort='str' width='".$widths[$key]."'>
     							&lt;div style='text-align:center;' &gt;".$key."&lt;/div&gt;
     						</column>\n
     					";
     				}
     			}
     			
     			else{
      				echo "<column type='ro' align='center' sort='str' width='150'>&lt;div style='text-align:center;'&gt;Date Created&lt;/div&gt;</column>\n" ;
      				echo "<column type='ro' align='center' sort='str' width='100'>&lt;div style='text-align:center;'&gt;User Name&lt;/div&gt;</column>\n" ;
      				echo "<column type='ro' align='center' sort='str' width='100'>&lt;div style='text-align:center;'&gt;Member type&lt;/div&gt;</column>\n" ;
      				echo "<column type='ro' align='center' sort='str' width='100'>&lt;div style='text-align:center;'&gt;IP address&lt;/div&gt;</column>\n" ;
      				
      				if(isset($this->serverDetails)){
						$this->get_variable();
      					foreach($this->serverData as $key=>$value){
							echo "<column type='ro' align='center' sort='str' width='100'>&lt;div style='text-align:center;'&gt;".$key."&lt;/div&gt;</column>\n" ;
						}
      				}

					if(is_array($this->otherDetails)){
						foreach($this->otherDetails as $key=>$value){
							echo "<column type='ro' align='center' sort='str' width='100'>&lt;div style='text-align:center;'&gt;".$key."&lt;/div&gt;</column>\n" ;
						}
					}
     			}
    			echo "</head>\n";
    			
    	if ($logDate){
    		include($this->save_path.'/AL-'.$logDate.'.xml');
    	}
    	else{
      		include($this->save_path.'/AL-'.date('Y-m-d').'.xml');
    	}
    	
    	echo "</rows>";
  		$xmldata = ob_get_clean();
  		return $xmldata;
	}
	
	
	/**
	 * rmkdir()
	 * 
	 * Makes directory and returns BOOL(TRUE) if exists OR made.
	 * http://php.net/manual/en/function.mkdir.php#83265
	 *
	 * @author gelamu@gmail.com
	 * @param  $path Path name
	 * @return bool
	 * 
	 */
	private function rmkdir($path, $mode = 0755) {
		
		$path = rtrim(preg_replace(array("/\\\\/", "/\/{2,}/"), "/", $path), "/");
		$e = explode("/", ltrim($path, "/"));
		if(substr($path, 0, 1) == "/") {
			$e[0] = "/".$e[0];
		}
		$c = count($e);
		$cp = $e[0];
		for($i = 1; $i < $c; $i++) {
			if(!is_dir($cp) && !@mkdir($cp, $mode)) {
				return false;
			}
			$cp .= "/".$e[$i];
		}
		return @mkdir($path, $mode);
	}
	
	
	
}
?>